@@ -1,9 +1,23 @@
-cmake <- biocmake::find()
+dir.create("inst", showWarnings=FALSE)
+version.target <- file.path("inst", "IGRAPH_VERSION")
+if (!file.exists(version.target)) {
+    if (!file.copy(file.path("igraph", "IGRAPH_VERSION"), version.target)) {
+        stop("failed to copy IGRAPH_VERSION")
+    }
+}
+
+if (Sys.getenv("RIGRAPHLIB_USE_SYSTEM_LIBRARY", "0") == "1") {
+    if (Sys.getenv("RIGRAPHLIB_FORCE_BUILD", "0") != "1") {
+        quit('no', status=0)
+    }
+}
 
 ###################################
 ######### Configuration ###########
 ###################################
 
+cmake <- biocmake::find()
+
 options <- biocmake::formatArguments(biocmake::configure(fortran.compiler=FALSE))
 options <- c(options, "-DIGRAPH_WARNINGS_AS_ERRORS=OFF")
 
@@ -51,7 +65,12 @@ if (!file.exists(install_path)) {
 
     if (!file.exists(build_path)) {
         source_path <- "igraph"
-        options <- c(options, paste0("-DCMAKE_INSTALL_PREFIX=", install_path))
+        options <- c(
+            options,
+            paste0("-DCMAKE_INSTALL_PREFIX=", install_path),
+            "-DCMAKE_PROJECT_NAME=Rigraphlib" # set this to prevent CMake from including irrelevant directories.
+        )
+
         if (system2(cmake, c("-S", source_path, "-B", build_path, options)) != 0) {
             stop("failed to configure the igraph library")
         }
@@ -62,7 +81,6 @@ if (!file.exists(install_path)) {
         stop("failed to build the igraph library")
     }
 
-    dir.create("inst", showWarnings=FALSE)
     if (system2(cmake, c("--install", build_path), stderr=FALSE) != 0) {
         stop("failed to install the igraph library")
     }
